@@ -4,7 +4,7 @@ def ask(question, default=None, alternatives=None):
     Arguments:
     - question (str): The text of the question.
     - default (any): Default value if no answer is provided.
-    - alternatives (str): Alternatives to display
+    - alternatives (str): Alternatives to display. eg: "Y/n"
     """
     ops = alternatives or default
     question += f" [{str(ops)}] " if ops else ""
