@@ -58,8 +58,7 @@ def parse_args(cliargs):  # noqa: C901
 
 
 def is_key(sarg):
-    """Check if `sarg` is a key (eg. -foo, --foo) or a negative number (eg. -33).
-    """
+    """Check if `sarg` is a key (eg. -foo, --foo) or a negative number (eg. -33)."""
     if not sarg.startswith("-"):
         return False
     if sarg.startswith("--"):
